@@ -4,10 +4,10 @@ from geospace.ras_to_shp import *
 from geospace.raster import *
 from geospace.shape import *
 from geospace.shp_to_ras import *
-from geospace.statistics import *
+from geospace.zonal_stats import *
 from geospace.projection import *
 from geospace.utils import *
-from geospace.gdal_calc import Calc
+from geospace.spatial_calc import *
 from geospace.map_calc import map_calc
 
 try:
